==> straw_0.23.orig.tar.gz: straw-0.23/src/lib/__init__.py <==
# Copyright (c) 2002 Juri Pakaste
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

cvs_id = "$Id: __init__.py,v 1.2 2004/04/16 20:26:07 jpakaste Exp $"

APPNAME = "Straw"
VERSION = "0.23"
STRAW_URL = "http://www.nongnu.org/straw/"
STRAW_REF_URL = "%sstraw-ref.html" % STRAW_URL

from Event import BaseSignal, SignalEmitter, ConfigOptionSignal, \
LocalConfigOptionSignal, FeedsChangedSignal, ItemsAddedSignal, \
ItemReadSignal,RefreshFeedDisplaySignal, NewItemsSignal, AllItemsReadSignal, \
ItemDeletedSignal, ImageUpdatedSignal, BlogURLChangedSignal, ItemOrderChangedSignal, \
OfflineModeChangedSignal, FindInterruptSignal, FeedPolledSignal, ItemStickySignal,FeedStatusChangedSignal, MainWindowSizeChangedSignal, \
MainPanePositionChangedSignal, SubPanePositionChangedSignal, \
NumberOfItemsStoredChangedSignal, SaveFeedsSignal, StatusDisplaySignal, \
FeedCategoriesChangedSignal, FeedDeletedSignal, FeedCreatedSignal, \
FeedErrorStatusChangedSignal, PollFrequencyChangedSignal
import Config
from Feed import Feed, create_empty_feed, create_new_feed
import FeedCategoryList
from FeedDataRouter import FeedDataRouter
import FeedList
from Main import Main
from MainWindow import MainWindow, CategorySelector
from PreferencesDialog import PreferencesDialog
from QueueDict import FeedQD
import SummaryParser
from ItemStore import ItemStore
from SummaryItem import SummaryItem
from ParsedSummary import ParsedSummary
import ImageCache
from ImageCache import Image
from SubscribeDialog import SubscribeDialog
from FindDialog import FindDialog
import file_selector
from FeedPropertiesDialog import FeedPropertiesDialog
import feedparser
import rssfinder
import hig_alert
import OPML
import OPMLImport
import OPMLExport
import NetworkConstants
import URLFetch
import PollManager
import LookupManager
from StrawURLOpener import StrawURLOpener
import DashboardFrontend
from FeedItems import FeedItems
import utils
import MessageManager

==> straw-0.24.tar.gz: straw-0.24/src/lib/__init__.py <==
# Copyright (c) 2002 Juri Pakaste
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

APPNAME = "Straw"
VERSION = "0.24"
STRAW_URL = "http://www.nongnu.org/straw/"
STRAW_REF_URL = "%sstraw-ref.html" % STRAW_URL

from Event import BaseSignal, SignalEmitter, ConfigOptionSignal, \
LocalConfigOptionSignal, FeedsChangedSignal, ItemsAddedSignal, \
ItemReadSignal,RefreshFeedDisplaySignal, NewItemsSignal, AllItemsReadSignal, \
ItemDeletedSignal, ImageUpdatedSignal, BlogURLChangedSignal, ItemOrderChangedSignal, \
OfflineModeChangedSignal, FindInterruptSignal, FeedPolledSignal, ItemStickySignal,FeedStatusChangedSignal, MainWindowSizeChangedSignal, \
MainPanePositionChangedSignal, SubPanePositionChangedSignal, \
NumberOfItemsStoredChangedSignal, SaveFeedsSignal, StatusDisplaySignal, \
FeedCategoriesChangedSignal, FeedDeletedSignal, FeedCreatedSignal, \
FeedErrorStatusChangedSignal, PollFrequencyChangedSignal, \
SubscriptionContentsUpdatedSignal, \
FeedCategoryChangedSignal, FeedCategoryListChangedSignal, \
FeedCategoryAddedSignal, FeedCategoryRemovedSignal, PollingStoppedSignal
import Config
from Feed import Feed, create_empty_feed, create_new_feed
import FeedCategoryList
from FeedDataRouter import FeedDataRouter
import FeedList
from Main import Main
from MainWindow import MainWindow, CategorySelector
from PreferencesDialog import PreferencesDialog
from QueueDict import FeedQD
import SummaryParser
from ItemStore import ItemStore
from SummaryItem import SummaryItem
from ParsedSummary import ParsedSummary
import ImageCache
from ImageCache import Image
from FindDialog import FindDialog
import file_selector
from FeedPropertiesDialog import FeedPropertiesDialog
import feedparser
import hig_alert
import OPML
import OPMLImport
import OPMLExport
import NetworkConstants
import URLFetch
import PollManager
import LookupManager
import DashboardFrontend
from FeedItems import FeedItems
import utils
import MessageManager
import Tray
import ValueMonitor
